<?php

namespace App\Console\Commands;

use Illuminate\Console\Command;
use App\Models\User;
use App\Models\Wallet;
use App\Models\SubWallet;
use App\Models\Transaction;
use App\Helpers\WalletHelper;

class AddOpeningBalances extends Command
{
    protected $signature = 'add-opening-balances';
    protected $description = 'Add opening balance transactions for existing users';

    public function handle()
    {
        $users = User::with('wallet.subWallets')->get();
        
        foreach ($users as $user) {
            $wallet = $user->wallet;
            
            if (!$wallet) continue;
            
            if ($user->role === 'beneficiary') {
                foreach ($wallet->subWallets as $subWallet) {
                    Transaction::firstOrCreate([
                        'wallet_id' => $wallet->id,
                        'sub_wallet_id' => $subWallet->id,
                        'type' => 'opening_balance',
                    ], [
                        'amount' => 0.00,
                        'reference' => WalletHelper::generateTransactionReference(),
                        'narration' => 'Retroactive opening balance',
                        'balance_before' => 0.00,
                        'balance_after' => 0.00,
                        'created_at' => $wallet->created_at,
                        'updated_at' => now(),
                    ]);
                }
            } else {
                Transaction::firstOrCreate([
                    'wallet_id' => $wallet->id,
                    'type' => 'opening_balance',
                ], [
                    'amount' => 0.00,
                    'reference' => WalletHelper::generateTransactionReference(),
                    'narration' => 'Retroactive opening balance',
                    'balance_before' => 0.00,
                    'balance_after' => 0.00,
                    'created_at' => $wallet->created_at,
                    'updated_at' => now(),
                ]);
            }
        }
        
        $this->info('Successfully added opening balances for all existing users!');
    }
}