<?php

namespace App\Exceptions;

use Exception;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class CardLockedException extends Exception
{
    /**
     * Create a new exception instance.
     */
    public function __construct(
        string $message = "Card is locked due to too many failed PIN attempts. Please contact support."
    ) {
        parent::__construct($message);
    }

    /**
     * Render the exception into an HTTP response.
     *
     * @param Request $request
     * @return Response|RedirectResponse
     */
    public function render(Request $request): Response|RedirectResponse
    {
        if ($request->expectsJson()) {
            return response()->json([
                'error' => $this->getMessage(),
                'status' => 403
            ], 403);
        }

        return redirect()
            ->back()
            ->withInput()
            ->withErrors(['pin' => $this->getMessage()]);
    }
}