<?php

namespace App\Exceptions;

use Illuminate\Foundation\Exceptions\Handler as ExceptionHandler;
use Throwable;
use App\Exceptions\InsufficientBalanceException;
use App\Exceptions\CategoryMismatchException;
use Illuminate\Support\Facades\Log;

class Handler extends ExceptionHandler
{
    /**
     * A list of exception types with their corresponding custom log levels.
     *
     * @var array<class-string<\Throwable>, \Psr\Log\LogLevel::*>
     */
    protected $levels = [
        //
    ];

    /**
     * A list of the exception types that are not reported.
     *
     * @var array<int, class-string<\Throwable>>
     */
    protected $dontReport = [
        //
    ];

    /**
     * A list of the inputs that are never flashed to the session on validation exceptions.
     *
     * @var array<int, string>
     */
    protected $dontFlash = [
        'current_password',
        'password',
        'password_confirmation',
    ];

    /**
     * Register the exception handling callbacks for the application.
     *
     * @return void
     */
    public function register(): void
    {
        $this->renderable(function (InvalidPinException $e, $request) {
            return response()->view('errors.invalid-pin', [
                'message' => $e->getMessage(),
                'attemptsLeft' => $e->getAttemptsLeft()
            ], 422);
        });

        $this->renderable(function (CardLockedException $e, $request) {
            return response()->view('errors.card-locked', [
                'message' => $e->getMessage()
            ], 403);
        });
    }

    /**
     * Render an exception into an HTTP response.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \Throwable  $exception
     * @return \Symfony\Component\HttpFoundation\Response
     *
     * @throws \Throwable
     */
    public function render($request, Throwable $exception)
    {
        // Handle insufficient balance exception
        if ($exception instanceof InsufficientBalanceException) {
            Log::warning('Insufficient balance: ' . $exception->getMessage());
            return redirect()
                ->back()
                ->withInput()
                ->with('error', $exception->getMessage());
        }

        // Handle category mismatch exception
        if ($exception instanceof CategoryMismatchException) {
            Log::warning('Category mismatch: ' . $exception->getMessage());
            return redirect()
                ->back()
                ->withInput()
                ->with('error', $exception->getMessage());
        }

        // Handle card locked exception (if you create one)
        if ($exception instanceof CardLockedException) {
            Log::warning('Card locked: ' . $exception->getMessage());
            return redirect()
                ->route('vendor.transact.form')
                ->with('error', $exception->getMessage());
        }

        // Handle invalid PIN exception (if you create one)
        if ($exception instanceof InvalidPinException) {
            Log::warning('Invalid PIN attempt: ' . $exception->getMessage());
            return redirect()
                ->back()
                ->withInput()
                ->with('error', $exception->getMessage());
        }

        return parent::render($request, $exception);
    }
}