<?php

namespace App\Exceptions;

use Exception;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;

class InvalidPinException extends Exception
{
    public function __construct(
        protected int $attemptsLeft,
        string $message = "Invalid PIN entered."
    ) {
        $message .= " Attempts left: {$this->attemptsLeft}";
        parent::__construct($message);
    }

    public function getAttemptsLeft(): int
    {
        return $this->attemptsLeft;
    }

    /**
     * Render the exception into an HTTP response.
     *
     * @param Request $request
     * @return Response|RedirectResponse
     */
    public function render(Request $request): Response|RedirectResponse
    {
        if ($request->expectsJson()) {
            return response()->json([
                'error' => $this->getMessage(),
                'attempts_left' => $this->attemptsLeft,
                'status' => 422
            ], 422);
        }

        return redirect()
            ->back()
            ->withInput()
            ->withErrors([
                'pin' => $this->getMessage(),
                'attempts_left' => $this->attemptsLeft
            ]);
    }
}