<?php

namespace App\Http\Controllers;

use App\Models\Card;
use App\Models\Transaction;
use App\Services\CardService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class AdminController extends Controller
{
    protected $cardService;

    public function __construct(CardService $cardService)
    {
        $this->cardService = $cardService;
    }

    // Show admin dashboard
    public function dashboard()
    {
        return view('admin.dashboard');
    }

    // Show card generation form
    public function showGenerateCardsForm()
    {
        return view('admin.generate-cards');
    }

    // Generate cards
    public function generateCards(Request $request)
    {
        // Allow only admins
        if (Auth::user()->role !== 'admin') {
            abort(403, 'Unauthorized action.');
        }

        // Validate the request
        $request->validate([
            'count' => 'required|integer|min:1|max:100',
        ]);

        // Generate cards
        for ($i = 0; $i < $request->count; $i++) {
            $cardNumber = $this->cardService->generateUniqueCardNumber();
            $qrPath = $this->cardService->generateQRCode($cardNumber);

            Card::create([
                'card_number' => $cardNumber,
                'qr_code_path' => $qrPath,
                'status' => 'inactive',
                'user_id' => null, // Leave as null
                'wallet_id' => null, // Leave as null
            ]);
        }

        return redirect()->back()->with('success', "{$request->count} cards generated!");
    }

    // View all cards
    public function viewCards()
    {
        $cards = Card::all();
        return view('admin.view-cards', compact('cards'));
    }

    // View all transactions
    public function viewTransactions()
    {
        $transactions = Transaction::all();
        return view('admin.view-transactions', compact('transactions'));
    }
}
