<?php

namespace App\Http\Controllers;

use App\Models\Kyc;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Notifications\KycStatusUpdated;

class AdminKycController extends Controller
{
    // List all pending KYC submissions
    public function index()
    {
        $kycs = Kyc::where('status', 'pending')->with('user')->paginate(10); // 10 items per page
        return view('admin.kyc.index', compact('kycs'));
    }

    // Show a single KYC submission
    public function show(Kyc $kyc)
    {
        return view('admin.kyc.show', compact('kyc'));
    }

    // Approve or reject a KYC submission
    public function update(Request $request, Kyc $kyc)
    {
        $request->validate([
            'status' => 'required|in:approved,rejected',
            'review_notes' => 'nullable|string',
        ]);

        $kyc->update([
            'status' => $request->status,
            'reviewed_by' => Auth::id(),
            'review_notes' => $request->review_notes,
        ]);

        // Notify the user about the KYC status update
        $kyc->user->notify(new KycStatusUpdated($kyc));

        return redirect()->route('admin.kyc.index')->with('success', 'KYC status updated successfully!');
    }
}
