<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller; // ✅ Ensure this is imported
use App\Models\User;
use Illuminate\Http\Request;

class UserController extends Controller
{
    /**
     * Show the authenticated user.
     */
    public function show(Request $request)
    {
        return response()->json($request->user());
    }

    /**
     * Update user details.
     */
    public function update(Request $request)
    {
        $user = $request->user();
        
        // Validate request data
        $request->validate([
            'name' => 'sometimes|string|max:255',
            'email' => 'sometimes|email|unique:users,email,' . $user->id,
        ]);

        // Update user details
        $user->update($request->only(['name', 'email']));
        
        return response()->json($user);
    }
}
