<?php

namespace App\Http\Controllers;

use App\Models\Kyc;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;

class KycController extends Controller
{
    // Show KYC submission form
    public function create()
    {
        return view('kyc.create');
    }

    // Store KYC submission
    public function store(Request $request)
    {
        $request->validate([
            'full_name' => 'required|string|max:255',
            'date_of_birth' => 'required|date',
            'gender' => 'required|in:male,female,other',
            'nationality' => 'required|string|max:255',
            'residential_address' => 'required|string|max:255',
            'phone_number' => 'required|string|max:20',
            'nin' => 'nullable|string|max:20',
            'id_type' => 'required|in:nin,passport,driver_license,pvc',
            'id_number' => 'required|string|max:255',
            'id_image' => 'required|image|mimes:jpeg,png,jpg|max:2048',
            'selfie' => 'required|image|mimes:jpeg,png,jpg|max:2048',
            'utility_bill' => 'required|file|mimes:pdf,jpeg,png,jpg|max:2048',
        ]);

        // Save uploaded files
        $idImagePath = $request->file('id_image')->store('kyc', 'public');
        $selfiePath = $request->file('selfie')->store('kyc', 'public');
        $utilityBillPath = $request->file('utility_bill')->store('kyc', 'public');

        // Create KYC record
        Kyc::create([
            'user_id' => Auth::id(),
            'full_name' => $request->full_name,
            'date_of_birth' => $request->date_of_birth,
            'gender' => $request->gender,
            'nationality' => $request->nationality,
            'residential_address' => $request->residential_address,
            'phone_number' => $request->phone_number,
            'nin' => $request->nin,
            'id_type' => $request->id_type,
            'id_number' => $request->id_number,
            'id_image' => $idImagePath,
            'selfie' => $selfiePath,
            'utility_bill' => $utilityBillPath,
        ]);

        return redirect()->route('dashboard')->with('success', 'KYC submitted successfully!');
    }
}