<?php

namespace App\Http\Middleware;

use Closure;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log; // For logging

class AdminMiddleware
{
    
    public function handle(Request $request, Closure $next): Response
    {
        // Log the user's role for debugging
        Log::info('AdminMiddleware: Checking user role', [
            'user_id' => Auth::id(),
            'role' => Auth::check() ? Auth::user()->role : 'guest',
        ]);

        // Check if the user is authenticated and has the 'admin' role
        if (Auth::check() && Auth::user()->role === 'admin') {
            return $next($request);
        }

        // Log unauthorized access attempts
        Log::warning('AdminMiddleware: Unauthorized access attempt', [
            'user_id' => Auth::id(),
            'ip' => $request->ip(),
        ]);

        // Abort with a 403 Forbidden error
        abort(403, 'Unauthorized access.');
    }
}