<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class Card extends Model
{
    protected $fillable = [
        'card_number',
        'hashed_pin', // Add this
        'user_id',
        'wallet_id',
        'qr_code_path',
        'activation_date',
        'expiry_date',
        'renewal_date',
        'status',
        'pin_attempts',
    ];

    // Link to User
    public function user()
    {
        return $this->belongsTo(User::class);
    }

    // Link to Wallet
    public function wallet()
    {
        return $this->belongsTo(Wallet::class);
    }

    // Link to Transactions
    public function transactions()
    {
        return $this->hasMany(Transaction::class);
    }

    // Automatically hash the PIN when setting it
    public function setHashedPinAttribute($value)
    {
        $this->attributes['hashed_pin'] = bcrypt($value);
    }

    // app/Models/Card.php
    protected static function booted()
    {
        static::retrieved(function ($card) {
            if ($card->pin_attempts >= 5 && $card->last_pin_attempt > now()->subHours(1)) {
                abort(403, 'Card locked. Contact support');
            }
        });
    }

    public function incrementPinAttempts()
    {
        $this->pin_attempts += 1;
        $this->last_pin_attempt = now();
        $this->save();
    }
}