<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;
use App\Models\Kyc;
use App\Models\Wallet;
use App\Models\SubWallet;
use App\Models\Transaction;
use Spatie\Permission\Traits\HasRoles;
use Illuminate\Support\Str;


class User extends Authenticatable
{


    use HasApiTokens, HasFactory, Notifiable, HasRoles;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'first_name',     // For beneficiary/donor registration
        'last_name',       // For beneficiary/donor registration
        //'name',           // Optional if you're using first_name/last_name instead
        'email',
        'password',
        'role',
        'phone',
        'business_name',  // For vendor registration
        'admin_name',     // For vendor registration
        'sector',         // For vendor registration (or use vendor_category if preferred)
        'country_code',
        'address',
        'vendor_category', // Optional; update as needed if you want to store vendor's category separately

        'name',
        'email',
        'phone',
        'password',
        'vendor_category',
        'role'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];

    /**
     * Relationship: Each user has one KYC.
     */
    public function kyc()
    {
        return $this->hasOne(Kyc::class);
    }

    /**
     * Relationship: A user that acts as a reviewer (if applicable).
     */
    public function reviewer()
    {
        return $this->belongsTo(User::class, 'reviewed_by');
    }

    /**
     * Relationship: Each vendor may have a vendor profile (if implemented separately).
     */
    public function vendor()
    {
        return $this->hasOne(Vendor::class);
    }

    public function getCategoriesAttribute()
    {
        return array_map('trim', explode(',', $this->vendor_category ?? ''));
    }

    /**
     * Relationship: Each user has one wallet.
     */
    public function wallet()
    {
        return $this->hasOne(Wallet::class);
    }

    /**
     * Relationship: Each user may have many sub-wallets through their wallet.
     */
    public function subWallets()
    {
        return $this->hasManyThrough(SubWallet::class, Wallet::class);
    }

    /**
     * Relationship: Each user may have many transactions.
     */
    public function transactions()
    {
        return $this->hasMany(Transaction::class);
    }

    public function payouts()
    {
        return $this->hasMany(Payout::class, 'user_id');
    }
}
