<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class Wallet extends Model
{
    protected $fillable = ['user_id', 'wallet_number', 'balance'];

    // Link to User
    public function user()
    {
        return $this->belongsTo(User::class);
    }

    // Link to Cards
    public function cards()
    {
        return $this->hasMany(Card::class);
    }

    public function transactions()
    {
        return $this->hasMany(Transaction::class);
    }

    public function subWallets()
    {
        return $this->hasMany(SubWallet::class);
    }

    // Create sub-wallets for a new wallet
    protected static function boot()
    {
        parent::boot();

        static::created(function ($wallet) {
            $categories = ['housing', 'education', 'health', 'food', 'finance', 'utility'];
            foreach ($categories as $category) {
                $wallet->subWallets()->create([
                    'category' => $category,
                    'balance' => 0.00,
                ]);
            }
        });
    }
}