<?php

namespace App\Notifications;

use App\Models\Transaction;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class FundingRequestNotification extends Notification implements ShouldQueue
{
    use Queueable;

    public $transaction;

    public function __construct(Transaction $transaction)
    {
        $this->transaction = $transaction;
    }

    public function via($notifiable)
    {
        return ['database', 'mail'];
    }

    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('New Funding Request')
            ->line('A new wallet funding request requires your approval.')
            ->action('Review Request', url('/admin/transactions/'.$this->transaction->id))
            ->line('Amount: ₦'.number_format($this->transaction->amount, 2));
    }

    public function toArray($notifiable)
    {
        return [
            'transaction_id' => $this->transaction->id,
            'amount' => $this->transaction->amount,
            'user_id' => $this->transaction->wallet->user->id,
            'message' => 'New funding request requires approval'
        ];
    }
}