<?php

namespace App\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class TransactionNotification extends Notification implements ShouldQueue
{
    use Queueable;

    public string $type;
    public float $amount;
    public string $category;

    /**
     * Create a new notification instance.
     */
    public function __construct(string $type, float $amount, string $category)
    {
        $this->type = $type;
        $this->amount = $amount;
        $this->category = $category;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail', 'database']; // Sends via mail and saves in database
    }

    /**
     * Get the mail representation of the notification.
     */
    public function toMail(object $notifiable): MailMessage
    {
        return (new MailMessage)
            ->subject('Transaction Notification')
            ->greeting("Hello, {$notifiable->name}!")
            ->line("A {$this->type} transaction of ₦{$this->amount} was recorded for {$this->category}.")
            ->action('View Transactions', url('/transactions'))
            ->line('Thank you for using our application!');
    }

    /**
     * Get the array representation of the notification.
     *
     * @return array<string, mixed>
     */
    public function toArray(object $notifiable): array
    {
        return [
            'type' => $this->type,
            'amount' => $this->amount,
            'category' => $this->category,
            'message' => "Transaction {$this->type} of ₦{$this->amount} for {$this->category}",
        ];
    }
}
