<?php

namespace App\Notifications;

use App\Models\Transaction;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class TransactionSuccess extends Notification implements ShouldQueue
{
    use Queueable;

    /**
     * The transaction instance
     * 
     * @var Transaction
     */
    public $transaction;

    /**
     * Create a new notification instance
     *
     * @param Transaction $transaction
     */
    public function __construct(Transaction $transaction)
    {
        $this->transaction = $transaction;
    }

    /**
     * Get the notification's delivery channels
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return ['database', 'mail'];
    }

    /**
     * Get the mail representation of the notification
     *
     * @param  mixed  $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
                    ->subject('Transaction Completed Successfully')
                    ->line('Your transaction was processed successfully.')
                    ->line('Amount: ₦'.number_format($this->transaction->amount, 2))
                    ->line('Reference: '.$this->transaction->reference)
                    ->action('View Transaction', url('/transactions/'.$this->transaction->id))
                    ->line('Thank you for using our service!');
    }

    /**
     * Get the array representation of the notification
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function toArray($notifiable)
    {
        return [
            'transaction_id' => $this->transaction->id,
            'amount' => $this->transaction->amount,
            'type' => $this->transaction->type,
            'reference' => $this->transaction->reference,
            'message' => 'Your transaction was completed successfully'
        ];
    }
}