<?php

namespace App\Services;

use App\Models\Card;
use SimpleSoftwareIO\QrCode\Facades\QrCode;
use Illuminate\Support\Facades\Storage;

class CardService
{
    // Generate a unique 11-digit card number
    public function generateUniqueCardNumber()
    {
        do {
            // Generate 11-digit number with no consecutive zeros
            do {
                $cardNumber = str_pad(mt_rand(0, 99999999999), 11, '0', STR_PAD_LEFT);
            } while (preg_match('/00/', $cardNumber)); // Reject if "00" exists
    
        } while (Card::where('card_number', $cardNumber)->exists());
    
        return $cardNumber;
    }

    // Generate QR code and save to storage
    public function generateQRCode($cardNumber)
    {
        $qrCode = QrCode::format('svg')->size(200)->generate($cardNumber);
        $path = "qrcodes/{$cardNumber}.svg";
        Storage::disk('public')->put($path, $qrCode);
        return $path;
    }

    // Activate a card
    public function activateCard(Card $card)
    {
        $card->update([
            'activation_date' => now(),
            'expiry_date' => now()->addYears(1),
            'status' => 'active'
        ]);
    }
}