<?php

namespace App\Services;

use App\Models\Transaction;
use App\Models\Wallet;
use App\Helpers\WalletHelper;
use Illuminate\Support\Facades\DB;

class DonationService
{
    public function processDonation($donorWallet, $amount, $cards, $category)
    {
        DB::beginTransaction();
        
        try {
            // Deduct from donor
            $this->createTransaction(
                $donorWallet,
                $amount,
                'debit',
                'donation',
                'Donation to cards'
            );

            // Distribute to beneficiaries
            foreach ($cards as $card) {
                $subWallet = $card->wallet->subWallets()
                    ->where('category', $category)
                    ->first();

                if ($subWallet) {
                    $this->createTransaction(
                        $subWallet->wallet,
                        $amount,
                        'credit',
                        $category,
                        'Donation received',
                        $subWallet->id
                    );
                }
            }

            DB::commit();
            return true;
        } catch (\Exception $e) {
            DB::rollBack();
            throw $e;
        }
    }

    private function createTransaction($wallet, $amount, $type, $category, $description, $subWalletId = null)
    {
        $transaction = Transaction::create([
            'wallet_id' => $wallet->id,
            'sub_wallet_id' => $subWalletId,
            'amount' => $amount,
            'type' => $type,
            'reference' => WalletHelper::generateTransactionReference(),
            'transaction_category' => $category,
            'description' => $description,
            'balance_before' => $wallet->balance,
            'balance_after' => $type === 'credit' 
                ? $wallet->balance + $amount 
                : $wallet->balance - $amount
        ]);

        $wallet->update(['balance' => $transaction->balance_after]);
        
        return $transaction;
    }
}