<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    // database/migrations/YYYY_MM_DD_HHMMSS_modify_transactions_table.php
    public function up()
    {
        Schema::table('transactions', function (Blueprint $table) {
            // 1. Drop foreign keys first (if they exist)
            $table->dropForeign(['card_id']);
            $table->dropForeign(['vendor_id']);

            // 2. Drop old columns
            $table->dropColumn(['card_id', 'vendor_id', 'donation_type']);

            // 3. Add new columns
            $table->unsignedBigInteger('wallet_id')->after('id');
            $table->unsignedBigInteger('sub_wallet_id')->nullable()->after('wallet_id');
            $table->string('reference')->unique();
            $table->decimal('balance_before', 10, 2)->default(0.00);
            $table->decimal('balance_after', 10, 2)->default(0.00);

            // 4. Rename description to narration
            $table->renameColumn('description', 'narration');

            // 5. Modify type enum
            $table->enum('type', ['opening_balance', 'credit', 'debit'])->change();
        });

        // 6. Add new foreign keys
        Schema::table('transactions', function (Blueprint $table) {
            $table->foreign('wallet_id')->references('id')->on('wallets');
            $table->foreign('sub_wallet_id')->references('id')->on('sub_wallets');
        });
    }

    public function down()
    {
        Schema::table('transactions', function (Blueprint $table) {
            // Reverse the operations
            $table->dropForeign(['wallet_id']);
            $table->dropForeign(['sub_wallet_id']);

            $table->dropColumn([
                'wallet_id',
                'sub_wallet_id',
                'reference',
                'balance_before',
                'balance_after'
            ]);

            $table->renameColumn('narration', 'description');
            $table->enum('type', ['credit', 'debit'])->change();

            // Add back original columns
            $table->unsignedBigInteger('card_id');
            $table->unsignedBigInteger('vendor_id');
            $table->enum('donation_type', ['card', 'bulk'])->nullable();
        });
    }
};
