<?php

require __DIR__ . '/vendor/autoload.php'; // Autoload Composer dependencies

use Endroid\QrCode\QrCode; // Use the QR code class
use Endroid\QrCode\Writer\PngWriter; // Use the PNG writer


// Database configuration
$host = 'localhost';
$database = 'akilaah';
$username = 'root';
$password = '';

// Connect to the database
try {
    // Check if PDO is available
    if (!extension_loaded('pdo')) {
        throw new Exception('PDO extension is not enabled.');
    }

    // Check if PDO MySQL driver is available
    if (!extension_loaded('pdo_mysql')) {
        throw new Exception('PDO MySQL driver is not enabled.');
    }

    // Create a PDO instance
    $pdo = new PDO("mysql:host=$host;dbname=$database", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION); // Enable exceptions for errors

    echo "Connected to the database successfully.\n";
} catch (Exception $e) {
    die("Database connection failed: " . $e->getMessage());
}

// Function to generate a unique 11-digit card number
function generateUniqueCardNumber(PDO $pdo): string
{
    do {
        // Generate 11-digit number with no consecutive zeros
        do {
            $cardNumber = str_pad(mt_rand(0, 99999999999), 11, '0', STR_PAD_LEFT);
        } while (preg_match('/00/', $cardNumber)); // Reject if "00" exists

        // Check if the card number already exists in the database
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM cards WHERE card_number = :card_number");
        $stmt->execute(['card_number' => $cardNumber]);
        $exists = $stmt->fetchColumn();
    } while ($exists > 0); // Regenerate if the number exists

    return $cardNumber;
}

// Function to generate and save a QR code
function generateQRCode(string $cardNumber): string
{
    // Create a QR code instance
    $qrCode = QrCode::create($cardNumber)
        ->setSize(200); // Set QR code size

    // Create a PNG writer
    $writer = new PngWriter();

    // Generate the QR code
    $result = $writer->write($qrCode);

    // Define the storage path
    $qrCodePath = 'qrcodes/' . $cardNumber . '.png';
    $storagePath = __DIR__ . '/public/' . $qrCodePath;

    // Ensure the directory exists
    if (!is_dir(dirname($storagePath))) {
        mkdir(dirname($storagePath), 0755, true);
    }

    // Save the QR code to the storage path
    $result->saveToFile($storagePath);

    return $qrCodePath;
}

// Generate and insert 5000 card numbers
$totalCards = 5000;
$insertedCards = 0;

echo "Generating 5000 card numbers...\n";

for ($i = 0; $i < $totalCards; $i++) {
    $cardNumber = generateUniqueCardNumber($pdo);
    $qrCodePath = generateQRCode($cardNumber); // Generate and save QR code

    // Insert the card into the database
    $stmt = $pdo->prepare("INSERT INTO cards (card_number, qr_code_path, status) VALUES (:card_number, :qr_code_path, 'inactive')");
    $stmt->execute([
        'card_number' => $cardNumber,
        'qr_code_path' => $qrCodePath,
    ]);

    $insertedCards++;
    echo "Inserted card: $cardNumber\n";
}

echo "Done! Inserted $insertedCards cards.\n";