<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Sign In | Akilaah</title>
    <link rel="icon" href="{{ asset('images/fav.png') }}" type="image/png">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">

    <style>
        body {
            min-height: 100vh;
            margin: 0;
            background-color: #fff;
            font-family: 'Nunito', sans-serif;
        }

        .top-nav {
            padding: 1rem;
        }

        .top-nav img {
            max-height: 36px;
        }

        .main-container {
            /*background: url('/images/splash-bg.jpg') no-repeat center bottom/cover;*/
            min-height: 100vh;
            display: flex;
            flex-direction: column;
            background: url('{{ asset('images/splash-bg.jpg') }}') no-repeat center center/cover;

        }

        .login-container {
            flex: 1;
            padding: 1rem;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .login-card {
            width: 100%;
            max-width: 440px;
            background: rgba(255, 255, 255, 0.98);
            border-radius: 8px;
            box-shadow: 0 4px 20px rgba(0, 32, 91, 0.1);
            padding: 1.5rem;
        }

        .brand-icon img {
            width: 42px;
            height: 42px;
        }

        .login-card h2 {
            font-size: 1.35rem;
            margin-bottom: 0.5rem;
            color: #333;
        }

        .login-card p {
            font-size: 0.9rem;
            margin-bottom: 1.5rem;
        }

        .form-label {
            font-size: 0.95rem;
            margin-bottom: 0.5rem;
        }

        .form-control {
            padding: 0.75rem 1rem;
            border-radius: 8px;
        }

        .toggle-password {
                cursor: pointer;
                position: absolute;
                right: 35px;  /* Increased from 15px for better spacing */
                top: 70%;
                transform: translateY(-50%);
                z-index: 5;
                color: #6c757d;
                background: transparent;
                border: none;
                height: 24px;
                width: 24px;
                display: flex;
                align-items: center;
                justify-content: center;
            }

        .btn-login {
            padding: 0.75rem;
            font-size: 0.95rem;
            background-color: #00205b;
            border-color: #0052cc;
        }

        .extra-links {
            font-size: 0.85rem;
        }

        @media (min-width: 768px) {
            .login-card {
                padding: 2rem;
                border-radius: 12px;
            }
            
            .top-nav {
                padding: 1.5rem 2rem;
            }

            .top-nav img {
                max-height: 40px;
            }

            .login-card h2 {
                font-size: 1.5rem;
            }

            .brand-icon img {
                width: 48px;
                height: 48px;
            }

            .toggle-password {
                cursor: pointer;
                position: absolute;
                right: 35px;  /* Increased from 15px for better spacing */
                top: 70%;
                transform: translateY(-50%);
                z-index: 5;
                color: #6c757d;
                background: transparent;
                border: none;
                height: 24px;
                width: 24px;
                display: flex;
                align-items: center;
                justify-content: center;
            }
        }

        @media (max-width: 576px) {
            .d-flex.justify-content-between {
                flex-direction: column;
                gap: 0.75rem;
                align-items: start;
            }
            
            .form-check-label {
                font-size: 0.9rem;
            }
            
            .extra-links p {
                margin-bottom: 0.75rem;
            }
            .toggle-password {
                cursor: pointer;
                position: absolute;
                right: 35px;  /* Increased from 15px for better spacing */
                top: 70%;
                transform: translateY(-50%);
                z-index: 5;
                color: #6c757d;
                background: transparent;
                border: none;
                height: 24px;
                width: 24px;
                display: flex;
                align-items: center;
                justify-content: center;
            }
        }
    </style>
</head>
<body>
    <div class="main-container">
        <!-- Top Navbar -->
        <nav class="top-nav">
            <a href="/">
                <img src="/images/akilaah-logo.png" alt="Akilaah Logo">
            </a>
        </nav>

        <!-- Login Content -->
        <div class="login-container">
            <div class="login-card">
                <div class="brand-icon text-center mb-3">
                    <img src="/images/fav.png" alt="Akilaah Icon" class="img-fluid">
                </div>
                <h2 class="text-center">Sign In</h2>
                <p class="text-center text-muted">Partner Account</p>

                <form method="POST" action="{{ route('login') }}">
                    @csrf

                    <!-- Email -->
                    <div class="mb-3">
                        <label for="email" class="form-label">Email Address</label>
                        <input id="email" type="email" 
                               class="form-control @error('email') is-invalid @enderror"
                               name="email" value="{{ old('email') }}" 
                               required autocomplete="email">
                        @error('email')
                        <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>

                    <!-- Password -->
                    <div class="mb-4 position-relative">
                        <label for="password" class="form-label">Password</label>
                        <input id="password" type="password"
                               class="form-control @error('password') is-invalid @enderror"
                               name="password" required 
                               autocomplete="current-password">
                        <i class="fa-solid fa-eye toggle-password" id="togglePasswordIcon"></i>
                        @error('password')
                        <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>

                    <!-- Remember & Forgot -->
                    <div class="d-flex justify-content-between align-items-center mb-4">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="remember" id="remember">
                            <label class="form-check-label" for="remember">Remember me</label>
                        </div>
                        @if (Route::has('password.request'))
                        <a href="{{ route('password.request') }}" class="text-decoration-none" style="color: #d49a22;">
                            Forgot Password?
                        </a>
                        @endif
                    </div>

                    <!-- Submit -->
                    <button type="submit" class="btn btn-login btn-primary w-100">
                        Sign In
                    </button>

                    <!-- Links -->
                    <div class="extra-links text-center mt-4">
                        <p class="mb-2">
                            Don’t have an account? <a href="{{ route('register') }}" style="color: #d49a22;">Sign Up</a>
                        </p>
                        <p>
                            Need direct debit? <a href="#" style="color: #d49a22;">Get Started</a>
                        </p>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Password Toggle
        const togglePasswordIcon = document.getElementById('togglePasswordIcon');
        const passwordField = document.getElementById('password');

        togglePasswordIcon.addEventListener('click', function() {
            const type = passwordField.getAttribute('type') === 'password' ? 'text' : 'password';
            passwordField.setAttribute('type', type);
            this.classList.toggle('fa-eye-slash');
        });
    </script>
</body>
</html>