<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Password Reset | Akilaah</title>
    <link rel="icon" href="{{ asset('images/fav.png') }}" type="image/png">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.1/font/bootstrap-icons.css">
    <style>
        body {
            min-height: 100vh;
            margin: 0;
            background-color: #fff;
            font-family: 'Nunito', sans-serif;
        }

        .auth-container {
            min-height: 100vh;
            background: url('{{ asset('images/splash-bg.jpg') }}') no-repeat center center/cover;
        }

        .reset-card {
            max-width: 440px;
            width: 100%;
            background: rgba(255, 255, 255, 0.98);
            border-radius: 12px;
            box-shadow: 0 8px 32px rgba(0, 32, 91, 0.1);
            padding: 2rem;
        }

        .nav-logo {
            height: 40px;
            transition: opacity 0.2s;
        }

        .brand-icon {
            color: #d49a22;
            font-size: 2rem;
            margin-bottom: 1rem;
        }

        .nav-tabs {
            border-bottom: none;
            margin: 1.5rem 0;
        }

        .nav-link {
            color: #666;
            border: none;
            padding: 0.5rem 1.25rem;
            position: relative;
        }

        .nav-link.active {
            color: #00205b;
            font-weight: 600;
        }

        .nav-link.active::after {
            content: '';
            position: absolute;
            bottom: -1px;
            left: 0;
            right: 0;
            height: 3px;
            background: #00205b;
        }

        .form-control, .form-select {
            border-radius: 8px;
            padding: 0.75rem 1rem;
        }

        .btn-reset {
            background-color: #00205b;
            color: #fff;
            padding: 0.75rem;
            font-weight: 600;
            transition: all 0.2s;
        }

        .btn-reset:hover {
            background-color: #001743;
            transform: translateY(-1px);
        }

        .input-group-text {
            background: #fff;
            border-right: 0;
        }

        .input-group select.form-select {
            border-right: 0;
            border-top-right-radius: 0;
            border-bottom-right-radius: 0;
        }

        .input-group input.form-control {
            border-left: 0;
            border-top-left-radius: 0;
            border-bottom-left-radius: 0;
        }

        @media (max-width: 768px) {
            .auth-container {
                padding: 1rem;
            }
            
            .reset-card {
                padding: 1.5rem;
            }
            
            .nav-link {
                padding: 0.5rem 1rem;
                font-size: 0.9rem;
            }
        }
    </style>
</head>
<body>
<div class="container-fluid auth-container">
    <div class="row g-0 min-vh-100">
        <div class="col-12">
            <!-- Top Navigation -->
            <nav class="px-3 px-lg-5 py-3">
                <a href="/">
                    <img src="{{ asset('images/akilaah-logo.png') }}" alt="Akilaah" class="nav-logo">
                </a>
            </nav>

            <!-- Reset Card -->
            <div class="d-flex justify-content-center align-items-center min-vh-75 px-3">
                <div class="reset-card">
                    <div class="text-center mb-4">
                        <i class="bi bi-shield-lock brand-icon"></i>
                        <h2 class="h4 mb-1">Password Reset</h2>
                    </div>

                    <!-- Tabs -->
                    <ul class="nav nav-tabs justify-content-center" id="resetTab">
                        <li class="nav-item">
                            <button class="nav-link active" data-bs-toggle="tab" data-bs-target="#phone-content">
                                Phone Number
                            </button>
                        </li>
                        <li class="nav-item">
                            <button class="nav-link" data-bs-toggle="tab" data-bs-target="#email-content">
                                Email
                            </button>
                        </li>
                    </ul>

                    <div class="tab-content mt-3">
                        <!-- Phone Tab -->
                        <div class="tab-pane fade show active" id="phone-content">
                            <form action="{{ route('password.phone') }}" method="POST">
                                @csrf
                                <div class="mb-3">
                                    <label class="form-label">Phone Number</label>
                                    <div class="input-group">
                                        <select class="form-select" name="country_code" style="max-width: 120px;">
                                            <option value="+234" selected>+234 NG</option>
                                        </select>
                                        <input type="tel" name="phone" class="form-control" 
                                               placeholder="801 234 5678" required>
                                    </div>
                                </div>

                                <div class="mb-4">
                                    <label class="form-label">Organization</label>
                                    <select name="organization" class="form-select" required>
                                        <option value="">Select Organization</option>
                                        <option value="org1">Organization 1</option>
                                        <option value="org2">Organization 2</option>
                                    </select>
                                </div>

                                <button type="submit" class="btn btn-reset w-100">
                                    Reset Password
                                </button>
                            </form>
                        </div>

                        <!-- Email Tab -->
                        <div class="tab-pane fade" id="email-content">
                            <form action="{{ route('password.email') }}" method="POST">
                                @csrf
                                <div class="mb-3">
                                    <label class="form-label">Email Address</label>
                                    <input type="email" name="email" class="form-control"
                                           placeholder="name@company.com" required>
                                </div>

                                <div class="mb-4">
                                    <label class="form-label">Organization</label>
                                    <select name="organization" class="form-select" required>
                                        <option value="">Select Organization</option>
                                        <option value="org1">Organization 1</option>
                                        <option value="org2">Organization 2</option>
                                    </select>
                                </div>

                                <button type="submit" class="btn btn-reset w-100">
                                    Reset Password
                                </button>
                            </form>
                        </div>
                    </div>

                    <!-- Sign In Link -->
                    <div class="text-center small mt-4">
                        Remember your password? 
                        <a href="{{ route('login') }}" class="text-decoration-none" style="color: #d49a22;">
                            Sign In
                        </a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>