<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Register - Akilaah</title>
    <link rel="icon" href="{{ asset('images/fav.png') }}" type="image/png">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- Bootstrap CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.1/font/bootstrap-icons.css">
    <link href="{{ mix('css/app.css') }}" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/flag-icons/6.6.6/css/flag-icons.min.css">

    <style>
        body {
            min-height: 100vh;
            margin: 0;
            padding: 0;
            background-color: #fff;
            font-family: 'Nunito', sans-serif;
        }

        .register-container {
            min-height: 100vh;
        }

        .register-left {
            background: url('/images/handshake.jpg') no-repeat center center/cover;
        }

        .register-right {
            padding: 1rem;
            display: flex;
            flex-direction: column;
            justify-content: center;
        }

        .register-header img {
            max-height: 50px;
            margin-bottom: 1rem;
        }

        .register-header h2 {
            font-size: 1.5rem;
            font-weight: 600;
            margin-bottom: 0.5rem;
            color: #1A1A1A;
        }

        .register-header h5 {
            font-size: 1rem;
            color: #555;
            margin-bottom: 1rem;
        }

        .needs-validation {
            padding: 1rem;
            border-radius: 0.5rem;
            background: white;
        }

        .form-label {
            font-weight: 500;
            color: #333;
        }

        .form-check-label a {
            color: #d49a22;
            text-decoration: none;
        }
        .form-check-label a:hover {
            text-decoration: underline;
        }

        .btn-primary {
            background-color: #00205b;
            border-color: #0052cc;
        }

        @media (min-width: 768px) {
            .register-right {
                padding: 2rem;
            }
            .register-header h2 {
                font-size: 1.75rem;
            }
            .register-header h5 {
                font-size: 1.1rem;
            }
            .needs-validation {
                padding: 1.5rem;
                box-shadow: 0 0 10px rgba(0,0,0,0.03);
                border: 1px solid #eaeaea;
            }
        }

        .password-toggle {
            cursor: pointer;
            position: absolute;
            right: 35px;  /* Increased from 15px for better spacing */
            top: 70%;
            transform: translateY(-50%);
            z-index: 5;
            color: #6c757d;
            background: transparent;
            border: none;
            height: 24px;
            width: 24px;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        /* Add padding to password inputs to prevent text overlap */
        .form-control[type="password"],
        .form-control[type="text"] {
            padding-right: 45px;  /* Space for the toggle icon */
        }

        /* Adjust position when there's validation error */
        .is-invalid ~ .password-toggle {
            right: 55px;  /* Make space for validation icon */
        }

        /* Nigerian flag styling */
        .fi-ng {
            background-image: url('data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 60 30"><path fill="#008751" d="M0 0h60v30H0z"/><path fill="white" d="M20 0h20v30H20z"/></svg>');
            width: 24px;
            height: 18px;
            background-size: cover;
            display: inline-block;
            vertical-align: middle;
        }

        /* Validation state adjustments */
        .is-invalid .fi-ng {
            filter: brightness(0.8);
        }
    </style>
</head>
<body>
<div class="container-fluid register-container">
    <div class="row h-100 g-0">
        <!-- Left column: handshake image -->
        <div class="col-md-6 register-left d-none d-md-block"></div>

        <!-- Right column: Registration form -->
        <div class="col-md-6 register-right">
            <div class="register-header mb-3 mb-md-4 text-center text-md-start">
                <img src="/images/akilaah-logo.png" alt="akilaah Logo" class="img-fluid">
                <h2>Vendor Registration</h2>
                <h5>Partner Account Creation</h5>
            </div>

            <form action="{{ route('register') }}" method="POST" class="needs-validation" novalidate>
                @csrf
                <input type="hidden" name="role" value="vendor">

                <!-- Vendor Fields -->
                <div class="row g-2">
                    <div class="col-12 col-md-6 mb-3">
                        <label for="business_name" class="form-label">Business Name <span class="text-danger">*</span></label>
                        <input type="text" name="business_name" id="business_name"
                               class="form-control @error('business_name') is-invalid @enderror"
                               value="{{ old('business_name') }}" required>
                        @error('business_name')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    <div class="col-12 col-md-6 mb-3">
                        <label for="admin_name" class="form-label">Admin Name <span class="text-danger">*</span></label>
                        <input type="text" name="admin_name" id="admin_name"
                               class="form-control @error('admin_name') is-invalid @enderror"
                               value="{{ old('admin_name') }}" required>
                        @error('admin_name')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>

                <div class="row g-2">
                    <div class="col-12 col-md-6 mb-3">
                        <label for="sector" class="form-label">Sector <span class="text-danger">*</span></label>
                        <select name="sector" id="sector" class="form-select @error('sector') is-invalid @enderror" required>
                            <option value="">Pick an option</option>
                            <option value="housing">Housing</option>
                            <option value="education">Education</option>
                            <option value="health">Health</option>
                            <option value="food">Food</option>
                            <option value="finance">Finance</option>
                            <option value="utility">Utility</option>
                        </select>
                        @error('sector')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>

                <!-- Contact Info -->
                <div class="row g-2">
                <div class="col-12 mb-3">
                        <label for="phone" class="form-label">Phone Number <span class="text-danger">*</span></label>
                        <div class="input-group">
                            <div class="input-group-prepend" style="width: 120px;">
                                <span class="input-group-text d-flex align-items-center gap-2 bg-white pe-2">
                                    <span class="fi fi-ng fis rounded"></span>
                                    +234
                                </span>
                            </div>
                            <input type="tel" name="phone" id="phone"
                                class="form-control @error('phone') is-invalid @enderror"
                                value="{{ old('phone') }}" 
                                placeholder="801 234 5678"
                                required>
                        </div>
                        @error('phone')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    <div class="col-12 mb-3">
                        <label for="email" class="form-label">Email <span class="text-danger">*</span></label>
                        <input type="email" name="email" id="email"
                               class="form-control @error('email') is-invalid @enderror"
                               value="{{ old('email') }}" required>
                        @error('email')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                </div>

                <!-- Password Fields -->
                <div class="row g-2">
                    <div class="col-12 col-md-6 mb-3 position-relative">
                        <label for="password" class="form-label">Password <span class="text-danger">*</span></label>
                        <input type="password" name="password" id="password"
                               class="form-control @error('password') is-invalid @enderror" required>
                        <i class="bi bi-eye-slash password-toggle" data-target="password"></i>
                        @error('password')
                            <div class="invalid-feedback">{{ $message }}</div>
                        @enderror
                    </div>
                    <div class="col-12 col-md-6 mb-3 position-relative">
                        <label for="password_confirmation" class="form-label">Confirm Password <span class="text-danger">*</span></label>
                        <input type="password" name="password_confirmation" id="password_confirmation"
                               class="form-control" required>
                        <i class="bi bi-eye-slash password-toggle" data-target="password_confirmation"></i>
                    </div>
                </div>

                <div class="mb-3">
                    <label for="address" class="form-label">Address <span class="text-danger">*</span></label>
                    <textarea name="address" id="address"
                              class="form-control @error('address') is-invalid @enderror"
                              rows="3" required>{{ old('address') }}</textarea>
                    @error('address')
                        <div class="invalid-feedback">{{ $message }}</div>
                    @enderror
                </div>

                <div class="mb-3 form-check">
                    <input type="checkbox" name="terms" id="terms"
                           class="form-check-input @error('terms') is-invalid @enderror" required>
                    <label class="form-check-label" for="terms">
                        By creating an account means you agree to the
                        <a href="{{ route('terms') }}">Terms and Conditions</a>,
                        and our <a href="{{ route('privacy') }}">Privacy Policy</a>
                    </label>
                    @error('terms')
                        <div class="invalid-feedback">{{ $message }}</div>
                    @enderror
                </div>

                <button type="submit" class="btn btn-primary w-100 py-2">Submit</button>
                <div class="mt-3 text-center form-check-label">
                    Already registered? <a href="{{ route('login') }}" class="text-decoration-none">Login here</a>
                </div>
            </form>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
document.querySelectorAll('.password-toggle').forEach(toggle => {
    toggle.addEventListener('click', function() {
        const target = document.getElementById(this.dataset.target);
        const type = target.type === 'password' ? 'text' : 'password';
        target.type = type;
        this.classList.toggle('bi-eye');
        this.classList.toggle('bi-eye-slash');
    });
});
</script>
</body>
</html>