@extends('layouts.beneficiary')

@section('page-title', 'Dashboard')

@section('vendor-content')
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-8">
            <div class="card">
                <!-- Card header with dashboard title and logout button -->
                <div class="card-header d-flex justify-content-between align-items-center">
                    <span>{{ __('Dashboard') }}</span>
                    <form id="logout-form" action="{{ route('logout') }}" method="POST" class="m-0">
                        @csrf
                        <button type="submit" class="btn btn-danger btn-sm">Logout</button>
                    </form>
                </div>

                <div class="card-body">
                    @if (session('status'))
                        <div class="alert alert-success" role="alert">
                            {{ session('status') }}
                        </div>
                    @endif

                    <h4>Welcome, {{ Auth::user()->name }}!</h4>
                    <p>Role: {{ Auth::user()->role }}</p>

                    <!-- Role-Specific Content -->
                    @if (Auth::user()->role === 'admin')
                        <div class="alert alert-info">
                            Admin Dashboard - Manage users, KYC approvals, and cards.
                        </div>
                    @elseif (Auth::user()->role === 'beneficiary')
                        <div class="alert alert-info">
                            Beneficiary Dashboard - View your wallet balance and cards.
                        </div>

                        <!-- KYC Submission Logic for Beneficiaries -->
                        @if (!Auth::user()->kyc || Auth::user()->kyc->status === 'rejected')
                            <a href="{{ route('kyc.create') }}" class="btn btn-primary">Submit KYC</a>
                        @elseif (Auth::user()->kyc->status === 'pending')
                            <div class="alert alert-warning mt-3">
                                Your KYC is under review.
                            </div>
                        @else
                            <div class="alert alert-success mt-3">
                                Your KYC is approved!
                            </div>
                        @endif

                        <!-- Display Sub-Wallets -->
                        <h5 class="mt-4">Your Sub-Wallets</h5>
                        <div class="row">
                            @foreach (Auth::user()->wallet->subWallets as $subWallet)
                                <div class="col-md-6 mb-3">
                                    <div class="card">
                                        <div class="card-header">{{ ucfirst($subWallet->category) }}</div>
                                        <div class="card-body">
                                            <p>Balance: {{ $subWallet->balance }}</p>
                                        </div>
                                    </div>
                                </div>
                            @endforeach
                        </div>

                    @elseif (Auth::user()->role === 'vendor')
                        <div class="alert alert-info">
                            Vendor Dashboard - Process transactions and view history.
                        </div>

                        <!-- KYC Submission Logic for Vendors -->
                        @if (!Auth::user()->kyc || Auth::user()->kyc->status === 'rejected')
                            <div class="alert alert-warning">
                                Your KYC is not verified. Please <a href="{{ route('kyc.create') }}">submit your KYC</a> to start transacting.
                            </div>
                        @elseif (Auth::user()->kyc->status === 'pending')
                            <div class="alert alert-warning">
                                Your KYC is under review. Transactions will be enabled once approved.
                            </div>
                        @else
                            <div class="alert alert-success">
                                Your KYC is approved! You can now process transactions.
                            </div>
                        @endif
                    @endif
                </div>
            </div>
        </div>
    </div>
</div>
@endsection
