<!-- resources/views/vendor/transact.blade.php -->
@extends('layouts.vendor')

@section('page-title', 'Dashboard')

@section('vendor-content')
    <div class="container">
        <h2>Process Transaction</h2>

        @if(session('success'))
            <div class="alert alert-success">
                {{ session('success') }}
            </div>
        @endif

        @if(session('error'))
            <div class="alert alert-danger">
                {{ session('error') }}
            </div>
        @endif


        <form method="POST" action="{{ route('vendor.transact.process') }}">
            @csrf

            <!-- Card Number -->
            <div class="mb-3">
                <label for="card_number" class="form-label">Card Number</label>
                <input type="text" name="card_number" id="card_number" class="form-control" value="{{ old('card_number') }}"
                    required>
                <small class="text-muted">Or scan QR code</small>
            </div>

            <!-- Amount -->
            <div class="mb-3">
                <label for="amount" class="form-label">Amount</label>
                <input type="number" name="amount" id="amount" class="form-control" min="1" value="{{ old('amount') }}"
                    required>
            </div>

            <!-- Category -->
            <div class="mb-3">
                <label for="category" class="form-label">Category</label>
                <select name="category" id="category" class="form-select" required>
                    @foreach($categories as $category)
                        <option value="{{ $category }}" {{ old('category') == $category ? 'selected' : '' }}>
                            {{ ucfirst($category) }}
                        </option>
                    @endforeach
                </select>
            </div>

            <!-- Description -->
            <div class="mb-3">
                <label for="description" class="form-label">Description</label>
                <input type="text" name="description" id="description" class="form-control" maxlength="70"
                    value="{{ old('description') }}" required>
            </div>

            <!-- PIN Verification -->
            <div class="mb-3">
                <label for="pin" class="form-label">Card PIN (4 digits)</label>
                <input type="password" name="pin" id="pin" class="form-control" pattern="\d{4}" title="4-digit PIN"
                    maxlength="4" required>
            </div>

            <button type="submit" class="btn btn-primary">
                Process Transaction
            </button>
            <!-- Add QR scanner button -->
            <button type="button" class="btn btn-secondary" id="scan-qr">
                <i class="fas fa-qrcode"></i> Scan QR
            </button>
        </form>

        
    </div>
@endsection



<!-- Add hidden input for QR result -->
<input type="hidden" id="qr-result">

@push('scripts')
    <script src="https://unpkg.com/html5-qrcode"></script>
    <script>
        const html5QrCode = new Html5Qrcode("reader");
        const qrScanner = new Html5QrcodeScanner('reader', { fps: 10, qrbox: 250 });

        document.getElementById('scan-qr').addEventListener('click', () => {
            Html5Qrcode.getCameras().then(devices => {
                if (devices && devices.length) {
                    html5QrCode.start(
                        devices[0].id,
                        {
                            fps: 10,
                            qrbox: 250
                        },
                        qrCode => {
                            document.querySelector('input[name="card_number"]').value = qrCode;
                            html5QrCode.stop();
                        },
                        error => console.error(error)
                    );
                }
            });
        });
    </script>
@endpush