<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\Api\TransactionController;
use App\Http\Controllers\Api\UserController;
use App\Http\Controllers\CardController;
use App\Http\Controllers\DonorController;
use App\Http\Controllers\Auth\RegisterController;

// Public Routes (No Authentication Required)
Route::post('/register', [AuthController::class, 'register']);
Route::post('/login', [AuthController::class, 'login']);

// Handle CORS Preflight Requests
Route::options('/{any}', function () {
    return response()->json([], 200);
})->where('any', '.*');

// Protected Routes (Requires Authentication)
Route::middleware('auth:sanctum')->group(function () {
    // User routes
    Route::put('/user', [UserController::class, 'update']); // Update user details
    Route::post('/logout', [AuthController::class, 'logout']); // Logout user

    // Card Management routes
    Route::prefix('cards')->group(function () {
        Route::post('/activate', [CardController::class, 'activate']);
        Route::post('/block', [CardController::class, 'block']);
        Route::post('/report-stolen', [CardController::class, 'reportStolen']);
    });

    // Transactions routes
    Route::get('/transactions', [TransactionController::class, 'index']);
    Route::post('/transactions', [TransactionController::class, 'store']);

    // Public registration endpoints
    Route::post('/register/donor', [RegisterController::class, 'registerDonor']);
    Route::post('/register/beneficiary', [RegisterController::class, 'registerBeneficiary']);

    // User profile endpoint
    Route::get('/user', function (Request $request) {
        return $request->user();
    });
});

Route::prefix('donor')->middleware('auth:sanctum')->group(function () {
    // Wallet Funding
    Route::post('/wallet/fund', [DonorController::class, 'fundWallet']);
    
    // Donation Processing
    Route::post('/donate', [DonorController::class, 'processDonation']);
    Route::post('/donate/bulk', [DonorController::class, 'processBulkDonation']);
    
    // Transaction History
    Route::get('/transactions', [DonorController::class, 'getTransactions']);
});