<!-- resources/views/vendors/dashboard.blade.php -->


<?php $__env->startSection('page-title', 'Dashboard'); ?>

<?php $__env->startSection('vendor-content'); ?>
    <style>
        .summary-card {
            background-color: #fff;
            border-radius: 0.5rem;
            border: 1px solid #eaeaea;
            padding: 1rem;
            text-align: center;
        }

        .summary-card h5 {
            font-size: 0.9rem;
            color: #999;
        }

        .summary-card h3 {
            font-size: 1.25rem;
            margin: 0.5rem 0;
        }

        .chart-container {
            background-color: #fff;
            border-radius: 0.5rem;
            border: 1px solid #eaeaea;
            padding: 1rem;
            min-height: 300px;
        }
    </style>

    <div class="container-fluid">
        <!-- Greeting Row -->
        <div class="d-flex justify-content-between align-items-center mb-4">
            <div>
                <?php
                    $hour = now()->format('H');
                    if ($hour < 12) {
                        $greeting = 'Good Morning';
                    } elseif ($hour < 17) {
                        $greeting = 'Good Afternoon';
                    } else {
                        $greeting = 'Good Evening';
                    }
                ?>

                <h3 class="m-0"><?php echo e($greeting); ?>, <?php echo e(Auth::user()->business_name); ?></h3>
                <small class="text-muted">Welcome back</small>
            </div>
            <?php if($kycWarning): ?>
                <div class="alert alert-warning d-flex align-items-center" role="alert">
                    <i class="bi bi-exclamation-triangle-fill me-2"></i>
                    <strong><?php echo e($kycWarning); ?></strong>
                    <a href="<?php echo e(route('vendor.settings')); ?>" class="ms-2 btn btn-sm btn-primary">Verify Now</a>
                </div>
            <?php endif; ?>
            <button class="btn btn-warning">
                <i class="fa fa-qrcode me-2"></i>Scan QR Code
            </button>
        </div>

        <!-- Account Summary -->
        <div class="row g-3 mb-4">
            <div class="col-md-3">
                <div class="summary-card">
                    <h5>Wallet Number</h5>
                    <h3><?php echo e($walletnumber ?? 'N/A'); ?></h3>
                </div>
            </div>
            <div class="col-md-3">
                <div class="summary-card">
                    <h5>Wallet Balance</h5>
                    <h3>₦<?php echo e(number_format($walletbalance, 2)); ?></h3>
                </div>
            </div>
            <div class="col-md-3">
                <div class="summary-card">
                    <h5>Pending Payouts</h5>
                    <h3>₦<?php echo e(number_format($pendingPayments, 2)); ?></h3>
                </div>
            </div>
            <div class="col-md-3">
                <div class="summary-card">
                    <h5>Total Payouts</h5>
                    <h3>₦<?php echo e(number_format($totalPayouts, 2)); ?></h3>
                </div>
            </div>
        </div>

        <!-- Charts Section -->
        <div class="row g-3 mb-4">
            <div class="col-md-6">
                <div class="chart-container">
                    <h5 class="mb-3">Category Report</h5>
                    <canvas id="productChart" style="width:100%; max-height:250px;"></canvas>
                </div>
            </div>
            <div class="col-md-6">
                <div class="chart-container">
                    <h5 class="mb-3">Transaction Report</h5>
                    <canvas id="transactionChart" style="width:100%; max-height:250px;"></canvas>
                </div>
            </div>
        </div>

        <!-- Recent Transactions -->
        <div class="mb-3 d-flex justify-content-between align-items-center">
            <h5 class="m-0">Recent Transactions</h5>
            <input type="text" id="transactionSearch" class="form-control form-control-sm w-25" placeholder="Search...">
        </div>

        <?php if(session('success')): ?>
            <div class="alert alert-success">
                <?php echo e(session('success')); ?>

            </div>
        <?php endif; ?>

        <?php if(session('error')): ?>
            <div class="alert alert-danger">
                <?php echo e(session('error')); ?>

            </div>
        <?php endif; ?>

        <div class="table-responsive">
            <table class="table align-middle table-striped">
                <thead>
                    <tr>
                        <th>Category</th>
                        <th>Description</th>
                        <th>Type</th>
                        <th>Amount</th>
                        <th>Date</th>
                    </tr>
                </thead>
                <tbody id="transactionTable">
                    <?php $__empty_1 = true; $__currentLoopData = $recentTransactions; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $transaction): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); $__empty_1 = false; ?>
                        <tr>
                            
                            <td><?php echo e(is_array($transaction) ? $transaction['transaction_category'] : $transaction->transaction_category); ?>

                            </td>
                            <td><?php echo e(is_array($transaction) ? $transaction['description'] : $transaction->description); ?></td>
                            <td>
                                <span
                                    class="badge bg-<?php echo e((is_array($transaction) ? $transaction['type'] : $transaction->type) === 'credit' ? 'success' : 'danger'); ?>">
                                    <?php echo e(strtoupper(is_array($transaction) ? $transaction['type'] : $transaction->type)); ?>

                                </span>
                            </td>
                            <td>₦<?php echo e(number_format(is_array($transaction) ? $transaction['amount'] : $transaction->amount, 2)); ?>

                            </td>
                            <td><?php echo e(\Carbon\Carbon::parse(is_array($transaction) ? $transaction['created_at'] : $transaction->created_at)->format('d/m/Y H:i')); ?>

                            </td>
                        </tr>
                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); if ($__empty_1): ?>
                        <tr>
                            <td colspan="5" class="text-center">No transactions found</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>

        <!-- Pagination -->
        <?php if($recentTransactions->hasPages()): ?>
            <div class="d-flex justify-content-between align-items-center mt-3">
                <p class="m-0">
                    Showing <?php echo e($recentTransactions->firstItem()); ?> to <?php echo e($recentTransactions->lastItem()); ?> of
                    <?php echo e($recentTransactions->total()); ?> results
                </p>
                <div>
                    <?php echo e($recentTransactions->links()); ?>

                </div>
            </div>
        <?php endif; ?>
    </div>



    <?php $__env->startPush('scripts'); ?>
        <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
        <script>
            // Transaction Search
            document.getElementById("transactionSearch").addEventListener("keyup", function () {
                let searchValue = this.value.toLowerCase();
                let rows = document.querySelectorAll("#transactionTable tr");

                rows.forEach(row => {
                    let text = row.innerText.toLowerCase();
                    row.style.display = text.includes(searchValue) ? "" : "none";
                });
            });

            // Category Chart
            document.addEventListener("DOMContentLoaded", function () {
                const categoryLabels = <?php echo json_encode($categoryLabels, 15, 512) ?>;
                const categoryTotals = <?php echo json_encode($categoryTotals, 15, 512) ?>;

                new Chart(document.getElementById('productChart').getContext('2d'), {
                    type: 'doughnut',
                    data: {
                        labels: categoryLabels,
                        datasets: [{
                            data: categoryTotals,
                            backgroundColor: ['#FF6384', '#36A2EB', '#FFCE56', '#4BC0C0', '#9966FF', '#FF9F40']
                        }]
                    },
                    options: {
                        responsive: true,
                        plugins: {
                            tooltip: {
                                callbacks: {
                                    label: (context) => {
                                        const label = context.label || '';
                                        const value = context.parsed || 0;
                                        return `${label}: ₦${value.toLocaleString()}`;
                                    }
                                }
                            }
                        }
                    }
                });
            });

            // Transaction Chart
            document.addEventListener("DOMContentLoaded", function () {
                const transactionMonths = <?php echo json_encode($transactionMonths, 15, 512) ?>;
                const transactionTotals = <?php echo json_encode($transactionTotals, 15, 512) ?>;

                new Chart(document.getElementById('transactionChart').getContext('2d'), {
                    type: 'line',
                    data: {
                        labels: transactionMonths,
                        datasets: [{
                            label: 'Transaction History',
                            data: transactionTotals,
                            borderColor: '#00205b',
                            backgroundColor: 'rgba(0,32,91,0.1)',
                            fill: true,
                            tension: 0.4
                        }]
                    },
                    options: {
                        responsive: true,
                        scales: {
                            y: {
                                beginAtZero: true,
                                ticks: {
                                    callback: (value) => `₦${value.toLocaleString()}`
                                }
                            }
                        }
                    }
                });
            });
        </script>
    <?php $__env->stopPush(); ?>
<?php $__env->stopSection(); ?>
<?php echo $__env->make('layouts.vendor', array_diff_key(get_defined_vars(), ['__data' => 1, '__path' => 1]))->render(); ?><?php /**PATH C:\xampp\htdocs\akilaah\resources\views/vendors/dashboard.blade.php ENDPATH**/ ?>