const { activate, block, reportStolen } = require('../lib/laravelClient');

describe('Card Service Integration Tests', () => {
    test('Successful card activation', async () => {
        // Mock valid credentials
        const result = await activate(
            '4111111111111111',
            'WALLET_123',
            '1234'
        );

        expect(result).toHaveProperty('status', 'success');
        expect(result.data).toHaveProperty('card');
    });

    test('Invalid PIN handling', async () => {
        await expect(activate(
            '4111111111111111',
            'WALLET_123',
            'wrong_pin'
        )).rejects.toMatchObject({
            status: 422,
            data: {
                message: expect.any(String)
            }
        });
    });

    // Add these below existing tests
    test('Block card functionality', async () => {
        const result = await block('4111111111111111', '1234');
        expect(result.status).toBe(200);
        expect(result.data).toHaveProperty('message', 'Card blocked successfully');
    });

    test('Stolen card reporting', async () => {
        const result = await reportStolen(
            '4111111111111111',
            'Stolen from coffee shop'
        );
        expect(result.data).toHaveProperty('reference_id');
    });
});

